==> huaweicloudsdkcce-3.1.134-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/upgrade_work_flow_update_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeWorkFlowUpdateRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'status': 'UpgradeWorkFlowUpdateRequestBodyStatus'
    }

    attribute_map = {
        'status': 'status'
    }

    def __init__(self, status=None):
        """UpgradeWorkFlowUpdateRequestBody

        The model defined in huaweicloud sdk

        :param status: 
        :type status: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        
        

        self._status = None
        self.discriminator = None

        if status is not None:
            self.status = status

    @property
    def status(self):
        """Gets the status of this UpgradeWorkFlowUpdateRequestBody.

        :return: The status of this UpgradeWorkFlowUpdateRequestBody.
        :rtype: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpgradeWorkFlowUpdateRequestBody.

        :param status: The status of this UpgradeWorkFlowUpdateRequestBody.
        :type status: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeWorkFlowUpdateRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/upgrade_work_flow_update_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeWorkFlowUpdateRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'status': 'UpgradeWorkFlowUpdateRequestBodyStatus'
    }

    attribute_map = {
        'status': 'status'
    }

    def __init__(self, status=None):
        r"""UpgradeWorkFlowUpdateRequestBody

        The model defined in huaweicloud sdk

        :param status: 
        :type status: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        
        

        self._status = None
        self.discriminator = None

        if status is not None:
            self.status = status

    @property
    def status(self):
        r"""Gets the status of this UpgradeWorkFlowUpdateRequestBody.

        :return: The status of this UpgradeWorkFlowUpdateRequestBody.
        :rtype: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this UpgradeWorkFlowUpdateRequestBody.

        :param status: The status of this UpgradeWorkFlowUpdateRequestBody.
        :type status: :class:`huaweicloudsdkcce.v3.UpgradeWorkFlowUpdateRequestBodyStatus`
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeWorkFlowUpdateRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
